==> suir-component-mapper-3.11.0.tgz: package/esm/form-template/form-template.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import SuirButton from "semantic-ui-react/dist/es/elements/Button/Button.js";
import Header from "semantic-ui-react/dist/es/elements/Header/Header.js";
import FormTemplate from '@data-driven-forms/common/form-template';

var Form = function Form(_ref) {
  var children = _ref.children,
      props = _objectWithoutProperties(_ref, ["children"]);

  return /*#__PURE__*/React.createElement("form", _extends({
    className: "ui form",
    noValidate: true
  }, props), children);
};

Form.propTypes = {
  children: PropTypes.node
};

var Description = function Description(_ref2) {
  var children = _ref2.children,
      props = _objectWithoutProperties(_ref2, ["children"]);

  return /*#__PURE__*/React.createElement("span", props, children);
};

Description.propTypes = {
  children: PropTypes.node
};

var Title = function Title(_ref3) {
  var children = _ref3.children,
      props = _objectWithoutProperties(_ref3, ["children"]);

  return /*#__PURE__*/React.createElement(Header, _extends({
    as: "h3"
  }, props), children);
};

Title.propTypes = {
  children: PropTypes.node
};

var ButtonGroup = function ButtonGroup(_ref4) {
  var children = _ref4.children,
      props = _objectWithoutProperties(_ref4, ["children"]);

  return /*#__PURE__*/React.createElement("div", props, children);
};

ButtonGroup.propTypes = {
  children: PropTypes.node
};

var Button = function Button(_ref5) {
  var label = _ref5.label,
      children = _ref5.children,
      buttonType = _ref5.buttonType,
      variant = _ref5.variant,
      props = _objectWithoutProperties(_ref5, ["label", "children", "buttonType", "variant"]);

  return /*#__PURE__*/React.createElement(SuirButton, _extends({
    color: variant === 'primary' ? 'blue' : undefined
  }, props), label || children);
};

Button.propTypes = {
  children: PropTypes.node,
  label: PropTypes.node,
  variant: PropTypes.string,
  buttonType: PropTypes.string
};

var MuiFormTemplate = function MuiFormTemplate(props) {
  return /*#__PURE__*/React.createElement(FormTemplate, _extends({
    FormWrapper: Form,
    Button: Button,
    ButtonGroup: ButtonGroup,
    Title: Title,
    Description: Description
  }, props));
};

export default MuiFormTemplate;

==> suir-component-mapper-3.18.0.tgz: package/esm/form-template/form-template.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["children"],
    _excluded2 = ["children"],
    _excluded3 = ["children"],
    _excluded4 = ["children"],
    _excluded5 = ["label", "children", "buttonType", "variant"];
import React from 'react';
import PropTypes from 'prop-types';
import SuirButton from "semantic-ui-react/dist/es/elements/Button/Button.js";
import Header from "semantic-ui-react/dist/es/elements/Header/Header.js";
import FormTemplate from '@data-driven-forms/common/form-template';

var Form = function Form(_ref) {
  var children = _ref.children,
      props = _objectWithoutProperties(_ref, _excluded);

  return /*#__PURE__*/React.createElement("form", _extends({
    className: "ui form",
    noValidate: true
  }, props), children);
};

Form.propTypes = {
  children: PropTypes.node
};

var Description = function Description(_ref2) {
  var children = _ref2.children,
      props = _objectWithoutProperties(_ref2, _excluded2);

  return /*#__PURE__*/React.createElement("span", props, children);
};

Description.propTypes = {
  children: PropTypes.node
};

var Title = function Title(_ref3) {
  var children = _ref3.children,
      props = _objectWithoutProperties(_ref3, _excluded3);

  return /*#__PURE__*/React.createElement(Header, _extends({
    as: "h3"
  }, props), children);
};

Title.propTypes = {
  children: PropTypes.node
};

var ButtonGroup = function ButtonGroup(_ref4) {
  var children = _ref4.children,
      props = _objectWithoutProperties(_ref4, _excluded4);

  return /*#__PURE__*/React.createElement("div", props, children);
};

ButtonGroup.propTypes = {
  children: PropTypes.node
};

var Button = function Button(_ref5) {
  var label = _ref5.label,
      children = _ref5.children,
      buttonType = _ref5.buttonType,
      variant = _ref5.variant,
      props = _objectWithoutProperties(_ref5, _excluded5);

  return /*#__PURE__*/React.createElement(SuirButton, _extends({
    color: variant === 'primary' ? 'blue' : undefined
  }, props), label || children);
};

Button.propTypes = {
  children: PropTypes.node,
  label: PropTypes.node,
  variant: PropTypes.string,
  buttonType: PropTypes.string
};

var MuiFormTemplate = function MuiFormTemplate(props) {
  return /*#__PURE__*/React.createElement(FormTemplate, _extends({
    FormWrapper: Form,
    Button: Button,
    ButtonGroup: ButtonGroup,
    Title: Title,
    Description: Description
  }, props));
};

export default MuiFormTemplate;
